@@ -63,6 +63,9 @@ def refresh_data(result, raw_data, data_to_check, session):
     result['Status'] = 'Published'
     result['Flags'] = '5'
 
+    ## filter species names that contain more than one word --> probably garbage, not usefull
+    result = result.loc[result['species'].str.split(' ').str.len() == 1]
+
     ## generate dicts to map to the input table
     genus = dict(zip(result['ID'], result['genus']))
     species = dict(zip(result['ID'], result['species']))
@@ -90,12 +93,16 @@ def refresh_data(result, raw_data, data_to_check, session):
     for id_pack in id_values:
         r = session.get('http://www.boldsystems.org/index.php/API_Public/specimen?ids={}&format=json'.format('|'.join(id_pack)))
         r = json.loads(r.text)['bold_records']['records']
-        ## loop through the ids of the response, collect data, append to responses
+        ## loop through the ids of the response, collect data, append to responses, handle responses with missing data
         for key in id_pack:
-            responses.append((r[key]['taxonomy']['phylum']['taxon']['name'],
-                              r[key]['taxonomy']['class']['taxon']['name'],
-                              r[key]['taxonomy']['order']['taxon']['name'],
-                              r[key]['taxonomy']['family']['taxon']['name']))
+            ## create an temporary list to collect the data
+            temp = []
+            for tax_level in ['phylum', 'class', 'order', 'family']:
+                try:
+                    temp.append(r[key]['taxonomy'][tax_level]['taxon']['name'])
+                except KeyError:
+                    temp.append(np.nan)
+            responses.append(temp)
 
     ## write the additional taxonomic information to a new dataframe and concat it to the one that's missing the data
     additional_tax = pd.DataFrame(responses,
